@@ -1,16 +1,16 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PROGRESSINDICATORLABEL_H
-#define PROGRESSINDICATORLABEL_H
+#pragma once
 
 #include "kdepim_export.h"
 
 #include <QWidget>
-namespace KPIM {
+namespace KPIM
+{
 class ProgressIndicatorLabelPrivate;
 /**
  * @brief The ProgressIndicatorLabel class
@@ -25,7 +25,7 @@ public:
      */
     explicit ProgressIndicatorLabel(const QString &labelStr, QWidget *parent = nullptr);
     explicit ProgressIndicatorLabel(QWidget *parent = nullptr);
-    ~ProgressIndicatorLabel();
+    ~ProgressIndicatorLabel() override;
 
     void setActiveLabel(const QString &label);
 
@@ -35,8 +35,7 @@ public Q_SLOTS:
 
 private:
     friend class ProgressIndicatorLabelPrivate;
-    ProgressIndicatorLabelPrivate *const d;
+    std::unique_ptr<ProgressIndicatorLabelPrivate> const d;
 };
 }
 
-#endif // PROGRESSINDICATORLABEL_H
